@@ -118,11 +118,6 @@ def _getInnerArticle_(soup, domain):
 					soup = candidate
 	if 'dq.yam.com' in domain:
 		return getDQ(soup)
-	try:
-		if str(soup.get('class')) == "['rich_media_content']":
-			soup['style'] = ''
-	except:
-		...
 	return soup
 
 def _getInnerArticle(soup, domain):
